| Title: | R/KEA Interface |
|---|---|
| Description: | An R interface to KEA (Version 5.0). KEA (for Keyphrase Extraction Algorithm) allows for extracting keyphrases from text documents. It can be either used for free indexing or for indexing with a controlled vocabulary. For more information see <http://www.nzdl.org/Kea/>. |
| Authors: | Ingo Feinerer [aut], Kurt Hornik [aut, cre] |
| Maintainer: | Kurt Hornik <[email protected]> |
| License: | GPL-2 |
| Version: | 0.0-6 |
| Built: | 2026-05-17 08:14:26 UTC |
| Source: | https://github.com/cran/RKEA |
Create a keyphrase extraction model.
createModel(corpus, keywords, model, voc = "none", vocformat = "")createModel(corpus, keywords, model, voc = "none", vocformat = "")
corpus |
A list of character vectors containing the text
documents, e.g., a |
keywords |
A list of character vectors containing the keywords
for each document in |
model |
A character giving the path where the created model should be stored. |
voc |
A character pointing to a controlled vocabulary. |
vocformat |
A character giving the format of |
A tutorial on keyword extraction is located at http://www.nzdl.org/Kea/Download/Kea-5.0-Readme.txt. There you can find details on the internals of KEA, including various parameter settings (e.g., details on vocabularies and supported formats for these).
When controlled vocabularies are used (by default: no), the voc
argument should give the file path to the respective files without
their extensions. When vocformat is "skos", the
extension must be ‘.rdf’; when "text", there must be files
with extensions ‘.en’, ‘.rel’ and ‘.use’.
Invisibly returns model, i.e., the path to the created KEA
model.
Ingo Feinerer
Extract keywords from text documents.
extractKeywords(corpus, model, voc = "none", vocformat = "")extractKeywords(corpus, model, voc = "none", vocformat = "")
corpus |
A list of character vectors containing the text
documents, e.g., a |
model |
A character giving the path to a KEA model. |
voc |
A character pointing to a controlled vocabulary. |
vocformat |
A character giving the format of |
A tutorial on keyword extraction is located at
http://www.nzdl.org/Kea/Download/Kea-5.0-Readme.txt. There you can
find details on the internals of KEA, including various parameter
settings (e.g., valid arguments for voc and vocformat).
A list of character vectors corresponding to the keywords in
corpus.
Ingo Feinerer